# aes_athlon_constants.s version 20050218
# D. J. Bernstein
# Public domain.

.data
.section .rodata
.p2align 5
.globl aes_athlon_constants
.globl aes_athlon_table0
.globl aes_athlon_table1
.globl aes_athlon_table2
.globl aes_athlon_table3

aes_athlon_constants:
aes_athlon_table0:
.byte 0xc6
aes_athlon_table3:
.byte 0x63
aes_athlon_table2:
.byte 0x63
aes_athlon_table1:
.byte 0xa5
.long 0xa56363c6
.long 0x847c7cf8
.long 0x847c7cf8
.long 0x997777ee
.long 0x997777ee
.long 0x8d7b7bf6
.long 0x8d7b7bf6
.long 0x0df2f2ff
.long 0x0df2f2ff
.long 0xbd6b6bd6
.long 0xbd6b6bd6
.long 0xb16f6fde
.long 0xb16f6fde
.long 0x54c5c591
.long 0x54c5c591
.long 0x50303060
.long 0x50303060
.long 0x03010102
.long 0x03010102
.long 0xa96767ce
.long 0xa96767ce
.long 0x7d2b2b56
.long 0x7d2b2b56
.long 0x19fefee7
.long 0x19fefee7
.long 0x62d7d7b5
.long 0x62d7d7b5
.long 0xe6abab4d
.long 0xe6abab4d
.long 0x9a7676ec
.long 0x9a7676ec
.long 0x45caca8f
.long 0x45caca8f
.long 0x9d82821f
.long 0x9d82821f
.long 0x40c9c989
.long 0x40c9c989
.long 0x877d7dfa
.long 0x877d7dfa
.long 0x15fafaef
.long 0x15fafaef
.long 0xeb5959b2
.long 0xeb5959b2
.long 0xc947478e
.long 0xc947478e
.long 0x0bf0f0fb
.long 0x0bf0f0fb
.long 0xecadad41
.long 0xecadad41
.long 0x67d4d4b3
.long 0x67d4d4b3
.long 0xfda2a25f
.long 0xfda2a25f
.long 0xeaafaf45
.long 0xeaafaf45
.long 0xbf9c9c23
.long 0xbf9c9c23
.long 0xf7a4a453
.long 0xf7a4a453
.long 0x967272e4
.long 0x967272e4
.long 0x5bc0c09b
.long 0x5bc0c09b
.long 0xc2b7b775
.long 0xc2b7b775
.long 0x1cfdfde1
.long 0x1cfdfde1
.long 0xae93933d
.long 0xae93933d
.long 0x6a26264c
.long 0x6a26264c
.long 0x5a36366c
.long 0x5a36366c
.long 0x413f3f7e
.long 0x413f3f7e
.long 0x02f7f7f5
.long 0x02f7f7f5
.long 0x4fcccc83
.long 0x4fcccc83
.long 0x5c343468
.long 0x5c343468
.long 0xf4a5a551
.long 0xf4a5a551
.long 0x34e5e5d1
.long 0x34e5e5d1
.long 0x08f1f1f9
.long 0x08f1f1f9
.long 0x937171e2
.long 0x937171e2
.long 0x73d8d8ab
.long 0x73d8d8ab
.long 0x53313162
.long 0x53313162
.long 0x3f15152a
.long 0x3f15152a
.long 0x0c040408
.long 0x0c040408
.long 0x52c7c795
.long 0x52c7c795
.long 0x65232346
.long 0x65232346
.long 0x5ec3c39d
.long 0x5ec3c39d
.long 0x28181830
.long 0x28181830
.long 0xa1969637
.long 0xa1969637
.long 0x0f05050a
.long 0x0f05050a
.long 0xb59a9a2f
.long 0xb59a9a2f
.long 0x0907070e
.long 0x0907070e
.long 0x36121224
.long 0x36121224
.long 0x9b80801b
.long 0x9b80801b
.long 0x3de2e2df
.long 0x3de2e2df
.long 0x26ebebcd
.long 0x26ebebcd
.long 0x6927274e
.long 0x6927274e
.long 0xcdb2b27f
.long 0xcdb2b27f
.long 0x9f7575ea
.long 0x9f7575ea
.long 0x1b090912
.long 0x1b090912
.long 0x9e83831d
.long 0x9e83831d
.long 0x742c2c58
.long 0x742c2c58
.long 0x2e1a1a34
.long 0x2e1a1a34
.long 0x2d1b1b36
.long 0x2d1b1b36
.long 0xb26e6edc
.long 0xb26e6edc
.long 0xee5a5ab4
.long 0xee5a5ab4
.long 0xfba0a05b
.long 0xfba0a05b
.long 0xf65252a4
.long 0xf65252a4
.long 0x4d3b3b76
.long 0x4d3b3b76
.long 0x61d6d6b7
.long 0x61d6d6b7
.long 0xceb3b37d
.long 0xceb3b37d
.long 0x7b292952
.long 0x7b292952
.long 0x3ee3e3dd
.long 0x3ee3e3dd
.long 0x712f2f5e
.long 0x712f2f5e
.long 0x97848413
.long 0x97848413
.long 0xf55353a6
.long 0xf55353a6
.long 0x68d1d1b9
.long 0x68d1d1b9
.long 0x00000000
.long 0x00000000
.long 0x2cededc1
.long 0x2cededc1
.long 0x60202040
.long 0x60202040
.long 0x1ffcfce3
.long 0x1ffcfce3
.long 0xc8b1b179
.long 0xc8b1b179
.long 0xed5b5bb6
.long 0xed5b5bb6
.long 0xbe6a6ad4
.long 0xbe6a6ad4
.long 0x46cbcb8d
.long 0x46cbcb8d
.long 0xd9bebe67
.long 0xd9bebe67
.long 0x4b393972
.long 0x4b393972
.long 0xde4a4a94
.long 0xde4a4a94
.long 0xd44c4c98
.long 0xd44c4c98
.long 0xe85858b0
.long 0xe85858b0
.long 0x4acfcf85
.long 0x4acfcf85
.long 0x6bd0d0bb
.long 0x6bd0d0bb
.long 0x2aefefc5
.long 0x2aefefc5
.long 0xe5aaaa4f
.long 0xe5aaaa4f
.long 0x16fbfbed
.long 0x16fbfbed
.long 0xc5434386
.long 0xc5434386
.long 0xd74d4d9a
.long 0xd74d4d9a
.long 0x55333366
.long 0x55333366
.long 0x94858511
.long 0x94858511
.long 0xcf45458a
.long 0xcf45458a
.long 0x10f9f9e9
.long 0x10f9f9e9
.long 0x06020204
.long 0x06020204
.long 0x817f7ffe
.long 0x817f7ffe
.long 0xf05050a0
.long 0xf05050a0
.long 0x443c3c78
.long 0x443c3c78
.long 0xba9f9f25
.long 0xba9f9f25
.long 0xe3a8a84b
.long 0xe3a8a84b
.long 0xf35151a2
.long 0xf35151a2
.long 0xfea3a35d
.long 0xfea3a35d
.long 0xc0404080
.long 0xc0404080
.long 0x8a8f8f05
.long 0x8a8f8f05
.long 0xad92923f
.long 0xad92923f
.long 0xbc9d9d21
.long 0xbc9d9d21
.long 0x48383870
.long 0x48383870
.long 0x04f5f5f1
.long 0x04f5f5f1
.long 0xdfbcbc63
.long 0xdfbcbc63
.long 0xc1b6b677
.long 0xc1b6b677
.long 0x75dadaaf
.long 0x75dadaaf
.long 0x63212142
.long 0x63212142
.long 0x30101020
.long 0x30101020
.long 0x1affffe5
.long 0x1affffe5
.long 0x0ef3f3fd
.long 0x0ef3f3fd
.long 0x6dd2d2bf
.long 0x6dd2d2bf
.long 0x4ccdcd81
.long 0x4ccdcd81
.long 0x140c0c18
.long 0x140c0c18
.long 0x35131326
.long 0x35131326
.long 0x2fececc3
.long 0x2fececc3
.long 0xe15f5fbe
.long 0xe15f5fbe
.long 0xa2979735
.long 0xa2979735
.long 0xcc444488
.long 0xcc444488
.long 0x3917172e
.long 0x3917172e
.long 0x57c4c493
.long 0x57c4c493
.long 0xf2a7a755
.long 0xf2a7a755
.long 0x827e7efc
.long 0x827e7efc
.long 0x473d3d7a
.long 0x473d3d7a
.long 0xac6464c8
.long 0xac6464c8
.long 0xe75d5dba
.long 0xe75d5dba
.long 0x2b191932
.long 0x2b191932
.long 0x957373e6
.long 0x957373e6
.long 0xa06060c0
.long 0xa06060c0
.long 0x98818119
.long 0x98818119
.long 0xd14f4f9e
.long 0xd14f4f9e
.long 0x7fdcdca3
.long 0x7fdcdca3
.long 0x66222244
.long 0x66222244
.long 0x7e2a2a54
.long 0x7e2a2a54
.long 0xab90903b
.long 0xab90903b
.long 0x8388880b
.long 0x8388880b
.long 0xca46468c
.long 0xca46468c
.long 0x29eeeec7
.long 0x29eeeec7
.long 0xd3b8b86b
.long 0xd3b8b86b
.long 0x3c141428
.long 0x3c141428
.long 0x79dedea7
.long 0x79dedea7
.long 0xe25e5ebc
.long 0xe25e5ebc
.long 0x1d0b0b16
.long 0x1d0b0b16
.long 0x76dbdbad
.long 0x76dbdbad
.long 0x3be0e0db
.long 0x3be0e0db
.long 0x56323264
.long 0x56323264
.long 0x4e3a3a74
.long 0x4e3a3a74
.long 0x1e0a0a14
.long 0x1e0a0a14
.long 0xdb494992
.long 0xdb494992
.long 0x0a06060c
.long 0x0a06060c
.long 0x6c242448
.long 0x6c242448
.long 0xe45c5cb8
.long 0xe45c5cb8
.long 0x5dc2c29f
.long 0x5dc2c29f
.long 0x6ed3d3bd
.long 0x6ed3d3bd
.long 0xefacac43
.long 0xefacac43
.long 0xa66262c4
.long 0xa66262c4
.long 0xa8919139
.long 0xa8919139
.long 0xa4959531
.long 0xa4959531
.long 0x37e4e4d3
.long 0x37e4e4d3
.long 0x8b7979f2
.long 0x8b7979f2
.long 0x32e7e7d5
.long 0x32e7e7d5
.long 0x43c8c88b
.long 0x43c8c88b
.long 0x5937376e
.long 0x5937376e
.long 0xb76d6dda
.long 0xb76d6dda
.long 0x8c8d8d01
.long 0x8c8d8d01
.long 0x64d5d5b1
.long 0x64d5d5b1
.long 0xd24e4e9c
.long 0xd24e4e9c
.long 0xe0a9a949
.long 0xe0a9a949
.long 0xb46c6cd8
.long 0xb46c6cd8
.long 0xfa5656ac
.long 0xfa5656ac
.long 0x07f4f4f3
.long 0x07f4f4f3
.long 0x25eaeacf
.long 0x25eaeacf
.long 0xaf6565ca
.long 0xaf6565ca
.long 0x8e7a7af4
.long 0x8e7a7af4
.long 0xe9aeae47
.long 0xe9aeae47
.long 0x18080810
.long 0x18080810
.long 0xd5baba6f
.long 0xd5baba6f
.long 0x887878f0
.long 0x887878f0
.long 0x6f25254a
.long 0x6f25254a
.long 0x722e2e5c
.long 0x722e2e5c
.long 0x241c1c38
.long 0x241c1c38
.long 0xf1a6a657
.long 0xf1a6a657
.long 0xc7b4b473
.long 0xc7b4b473
.long 0x51c6c697
.long 0x51c6c697
.long 0x23e8e8cb
.long 0x23e8e8cb
.long 0x7cdddda1
.long 0x7cdddda1
.long 0x9c7474e8
.long 0x9c7474e8
.long 0x211f1f3e
.long 0x211f1f3e
.long 0xdd4b4b96
.long 0xdd4b4b96
.long 0xdcbdbd61
.long 0xdcbdbd61
.long 0x868b8b0d
.long 0x868b8b0d
.long 0x858a8a0f
.long 0x858a8a0f
.long 0x907070e0
.long 0x907070e0
.long 0x423e3e7c
.long 0x423e3e7c
.long 0xc4b5b571
.long 0xc4b5b571
.long 0xaa6666cc
.long 0xaa6666cc
.long 0xd8484890
.long 0xd8484890
.long 0x05030306
.long 0x05030306
.long 0x01f6f6f7
.long 0x01f6f6f7
.long 0x120e0e1c
.long 0x120e0e1c
.long 0xa36161c2
.long 0xa36161c2
.long 0x5f35356a
.long 0x5f35356a
.long 0xf95757ae
.long 0xf95757ae
.long 0xd0b9b969
.long 0xd0b9b969
.long 0x91868617
.long 0x91868617
.long 0x58c1c199
.long 0x58c1c199
.long 0x271d1d3a
.long 0x271d1d3a
.long 0xb99e9e27
.long 0xb99e9e27
.long 0x38e1e1d9
.long 0x38e1e1d9
.long 0x13f8f8eb
.long 0x13f8f8eb
.long 0xb398982b
.long 0xb398982b
.long 0x33111122
.long 0x33111122
.long 0xbb6969d2
.long 0xbb6969d2
.long 0x70d9d9a9
.long 0x70d9d9a9
.long 0x898e8e07
.long 0x898e8e07
.long 0xa7949433
.long 0xa7949433
.long 0xb69b9b2d
.long 0xb69b9b2d
.long 0x221e1e3c
.long 0x221e1e3c
.long 0x92878715
.long 0x92878715
.long 0x20e9e9c9
.long 0x20e9e9c9
.long 0x49cece87
.long 0x49cece87
.long 0xff5555aa
.long 0xff5555aa
.long 0x78282850
.long 0x78282850
.long 0x7adfdfa5
.long 0x7adfdfa5
.long 0x8f8c8c03
.long 0x8f8c8c03
.long 0xf8a1a159
.long 0xf8a1a159
.long 0x80898909
.long 0x80898909
.long 0x170d0d1a
.long 0x170d0d1a
.long 0xdabfbf65
.long 0xdabfbf65
.long 0x31e6e6d7
.long 0x31e6e6d7
.long 0xc6424284
.long 0xc6424284
.long 0xb86868d0
.long 0xb86868d0
.long 0xc3414182
.long 0xc3414182
.long 0xb0999929
.long 0xb0999929
.long 0x772d2d5a
.long 0x772d2d5a
.long 0x110f0f1e
.long 0x110f0f1e
.long 0xcbb0b07b
.long 0xcbb0b07b
.long 0xfc5454a8
.long 0xfc5454a8
.long 0xd6bbbb6d
.long 0xd6bbbb6d
.long 0x3a16162c
.long 0x3a16162c
