# poly1305_macos_constants.s version 20050207
# D. J. Bernstein
# Public domain.

.const
.align 4
.globl _poly1305_macos_constants
.globl poly1305_macos_constants

_poly1305_macos_constants:
poly1305_macos_constants:
.long 0x3e380000
.long 0x0
.long 0x40380000
.long 0x0
.long 0x42380000
.long 0x0
.long 0x43380000
.long 0x0
.long 0x44580000
.long 0x0
.long 0x45380000
.long 0x0
.long 0x46580000
.long 0x0
.long 0x47380000
.long 0x0
.long 0x48580000
.long 0x0
.long 0x49380000
.long 0x0
.long 0x4a380000
.long 0x0
.long 0x4b580000
.long 0x0
.long 0x37f40000
.long 0x0
.long 0x43380001
.long 0xfffffffb
.long 0x45380001
.long 0xfffffffe
.long 0x47380001
.long 0xfffffffe
.long 0x49380003
.long 0xfffffffe
