# aes_aix_constants.s version 20050205
# D. J. Bernstein
# Public domain.

.globl aes_aix_constants

.toc
.csect aes_aix_constants[RO],5

.long 0x00000000
.long 0x00000000
.long 0x00000000
.long 0x00000000
.long 0x00000000
.long 0x00000000
.long 0x01000000
.long 0x02000000
.long 0x04000000
.long 0x08000000
.long 0x10000000
.long 0x20000000
.long 0x40000000
.long 0x80000000
.long 0x1b000000
.long 0x36000000
aes_aix_constants:
.long 0xc66363a5
.long 0xc66363a5
.long 0xf87c7c84
.long 0xf87c7c84
.long 0xee777799
.long 0xee777799
.long 0xf67b7b8d
.long 0xf67b7b8d
.long 0xfff2f20d
.long 0xfff2f20d
.long 0xd66b6bbd
.long 0xd66b6bbd
.long 0xde6f6fb1
.long 0xde6f6fb1
.long 0x91c5c554
.long 0x91c5c554
.long 0x60303050
.long 0x60303050
.long 0x02010103
.long 0x02010103
.long 0xce6767a9
.long 0xce6767a9
.long 0x562b2b7d
.long 0x562b2b7d
.long 0xe7fefe19
.long 0xe7fefe19
.long 0xb5d7d762
.long 0xb5d7d762
.long 0x4dababe6
.long 0x4dababe6
.long 0xec76769a
.long 0xec76769a
.long 0x8fcaca45
.long 0x8fcaca45
.long 0x1f82829d
.long 0x1f82829d
.long 0x89c9c940
.long 0x89c9c940
.long 0xfa7d7d87
.long 0xfa7d7d87
.long 0xeffafa15
.long 0xeffafa15
.long 0xb25959eb
.long 0xb25959eb
.long 0x8e4747c9
.long 0x8e4747c9
.long 0xfbf0f00b
.long 0xfbf0f00b
.long 0x41adadec
.long 0x41adadec
.long 0xb3d4d467
.long 0xb3d4d467
.long 0x5fa2a2fd
.long 0x5fa2a2fd
.long 0x45afafea
.long 0x45afafea
.long 0x239c9cbf
.long 0x239c9cbf
.long 0x53a4a4f7
.long 0x53a4a4f7
.long 0xe4727296
.long 0xe4727296
.long 0x9bc0c05b
.long 0x9bc0c05b
.long 0x75b7b7c2
.long 0x75b7b7c2
.long 0xe1fdfd1c
.long 0xe1fdfd1c
.long 0x3d9393ae
.long 0x3d9393ae
.long 0x4c26266a
.long 0x4c26266a
.long 0x6c36365a
.long 0x6c36365a
.long 0x7e3f3f41
.long 0x7e3f3f41
.long 0xf5f7f702
.long 0xf5f7f702
.long 0x83cccc4f
.long 0x83cccc4f
.long 0x6834345c
.long 0x6834345c
.long 0x51a5a5f4
.long 0x51a5a5f4
.long 0xd1e5e534
.long 0xd1e5e534
.long 0xf9f1f108
.long 0xf9f1f108
.long 0xe2717193
.long 0xe2717193
.long 0xabd8d873
.long 0xabd8d873
.long 0x62313153
.long 0x62313153
.long 0x2a15153f
.long 0x2a15153f
.long 0x0804040c
.long 0x0804040c
.long 0x95c7c752
.long 0x95c7c752
.long 0x46232365
.long 0x46232365
.long 0x9dc3c35e
.long 0x9dc3c35e
.long 0x30181828
.long 0x30181828
.long 0x379696a1
.long 0x379696a1
.long 0x0a05050f
.long 0x0a05050f
.long 0x2f9a9ab5
.long 0x2f9a9ab5
.long 0x0e070709
.long 0x0e070709
.long 0x24121236
.long 0x24121236
.long 0x1b80809b
.long 0x1b80809b
.long 0xdfe2e23d
.long 0xdfe2e23d
.long 0xcdebeb26
.long 0xcdebeb26
.long 0x4e272769
.long 0x4e272769
.long 0x7fb2b2cd
.long 0x7fb2b2cd
.long 0xea75759f
.long 0xea75759f
.long 0x1209091b
.long 0x1209091b
.long 0x1d83839e
.long 0x1d83839e
.long 0x582c2c74
.long 0x582c2c74
.long 0x341a1a2e
.long 0x341a1a2e
.long 0x361b1b2d
.long 0x361b1b2d
.long 0xdc6e6eb2
.long 0xdc6e6eb2
.long 0xb45a5aee
.long 0xb45a5aee
.long 0x5ba0a0fb
.long 0x5ba0a0fb
.long 0xa45252f6
.long 0xa45252f6
.long 0x763b3b4d
.long 0x763b3b4d
.long 0xb7d6d661
.long 0xb7d6d661
.long 0x7db3b3ce
.long 0x7db3b3ce
.long 0x5229297b
.long 0x5229297b
.long 0xdde3e33e
.long 0xdde3e33e
.long 0x5e2f2f71
.long 0x5e2f2f71
.long 0x13848497
.long 0x13848497
.long 0xa65353f5
.long 0xa65353f5
.long 0xb9d1d168
.long 0xb9d1d168
.long 0x00000000
.long 0x00000000
.long 0xc1eded2c
.long 0xc1eded2c
.long 0x40202060
.long 0x40202060
.long 0xe3fcfc1f
.long 0xe3fcfc1f
.long 0x79b1b1c8
.long 0x79b1b1c8
.long 0xb65b5bed
.long 0xb65b5bed
.long 0xd46a6abe
.long 0xd46a6abe
.long 0x8dcbcb46
.long 0x8dcbcb46
.long 0x67bebed9
.long 0x67bebed9
.long 0x7239394b
.long 0x7239394b
.long 0x944a4ade
.long 0x944a4ade
.long 0x984c4cd4
.long 0x984c4cd4
.long 0xb05858e8
.long 0xb05858e8
.long 0x85cfcf4a
.long 0x85cfcf4a
.long 0xbbd0d06b
.long 0xbbd0d06b
.long 0xc5efef2a
.long 0xc5efef2a
.long 0x4faaaae5
.long 0x4faaaae5
.long 0xedfbfb16
.long 0xedfbfb16
.long 0x864343c5
.long 0x864343c5
.long 0x9a4d4dd7
.long 0x9a4d4dd7
.long 0x66333355
.long 0x66333355
.long 0x11858594
.long 0x11858594
.long 0x8a4545cf
.long 0x8a4545cf
.long 0xe9f9f910
.long 0xe9f9f910
.long 0x04020206
.long 0x04020206
.long 0xfe7f7f81
.long 0xfe7f7f81
.long 0xa05050f0
.long 0xa05050f0
.long 0x783c3c44
.long 0x783c3c44
.long 0x259f9fba
.long 0x259f9fba
.long 0x4ba8a8e3
.long 0x4ba8a8e3
.long 0xa25151f3
.long 0xa25151f3
.long 0x5da3a3fe
.long 0x5da3a3fe
.long 0x804040c0
.long 0x804040c0
.long 0x058f8f8a
.long 0x058f8f8a
.long 0x3f9292ad
.long 0x3f9292ad
.long 0x219d9dbc
.long 0x219d9dbc
.long 0x70383848
.long 0x70383848
.long 0xf1f5f504
.long 0xf1f5f504
.long 0x63bcbcdf
.long 0x63bcbcdf
.long 0x77b6b6c1
.long 0x77b6b6c1
.long 0xafdada75
.long 0xafdada75
.long 0x42212163
.long 0x42212163
.long 0x20101030
.long 0x20101030
.long 0xe5ffff1a
.long 0xe5ffff1a
.long 0xfdf3f30e
.long 0xfdf3f30e
.long 0xbfd2d26d
.long 0xbfd2d26d
.long 0x81cdcd4c
.long 0x81cdcd4c
.long 0x180c0c14
.long 0x180c0c14
.long 0x26131335
.long 0x26131335
.long 0xc3ecec2f
.long 0xc3ecec2f
.long 0xbe5f5fe1
.long 0xbe5f5fe1
.long 0x359797a2
.long 0x359797a2
.long 0x884444cc
.long 0x884444cc
.long 0x2e171739
.long 0x2e171739
.long 0x93c4c457
.long 0x93c4c457
.long 0x55a7a7f2
.long 0x55a7a7f2
.long 0xfc7e7e82
.long 0xfc7e7e82
.long 0x7a3d3d47
.long 0x7a3d3d47
.long 0xc86464ac
.long 0xc86464ac
.long 0xba5d5de7
.long 0xba5d5de7
.long 0x3219192b
.long 0x3219192b
.long 0xe6737395
.long 0xe6737395
.long 0xc06060a0
.long 0xc06060a0
.long 0x19818198
.long 0x19818198
.long 0x9e4f4fd1
.long 0x9e4f4fd1
.long 0xa3dcdc7f
.long 0xa3dcdc7f
.long 0x44222266
.long 0x44222266
.long 0x542a2a7e
.long 0x542a2a7e
.long 0x3b9090ab
.long 0x3b9090ab
.long 0x0b888883
.long 0x0b888883
.long 0x8c4646ca
.long 0x8c4646ca
.long 0xc7eeee29
.long 0xc7eeee29
.long 0x6bb8b8d3
.long 0x6bb8b8d3
.long 0x2814143c
.long 0x2814143c
.long 0xa7dede79
.long 0xa7dede79
.long 0xbc5e5ee2
.long 0xbc5e5ee2
.long 0x160b0b1d
.long 0x160b0b1d
.long 0xaddbdb76
.long 0xaddbdb76
.long 0xdbe0e03b
.long 0xdbe0e03b
.long 0x64323256
.long 0x64323256
.long 0x743a3a4e
.long 0x743a3a4e
.long 0x140a0a1e
.long 0x140a0a1e
.long 0x924949db
.long 0x924949db
.long 0x0c06060a
.long 0x0c06060a
.long 0x4824246c
.long 0x4824246c
.long 0xb85c5ce4
.long 0xb85c5ce4
.long 0x9fc2c25d
.long 0x9fc2c25d
.long 0xbdd3d36e
.long 0xbdd3d36e
.long 0x43acacef
.long 0x43acacef
.long 0xc46262a6
.long 0xc46262a6
.long 0x399191a8
.long 0x399191a8
.long 0x319595a4
.long 0x319595a4
.long 0xd3e4e437
.long 0xd3e4e437
.long 0xf279798b
.long 0xf279798b
.long 0xd5e7e732
.long 0xd5e7e732
.long 0x8bc8c843
.long 0x8bc8c843
.long 0x6e373759
.long 0x6e373759
.long 0xda6d6db7
.long 0xda6d6db7
.long 0x018d8d8c
.long 0x018d8d8c
.long 0xb1d5d564
.long 0xb1d5d564
.long 0x9c4e4ed2
.long 0x9c4e4ed2
.long 0x49a9a9e0
.long 0x49a9a9e0
.long 0xd86c6cb4
.long 0xd86c6cb4
.long 0xac5656fa
.long 0xac5656fa
.long 0xf3f4f407
.long 0xf3f4f407
.long 0xcfeaea25
.long 0xcfeaea25
.long 0xca6565af
.long 0xca6565af
.long 0xf47a7a8e
.long 0xf47a7a8e
.long 0x47aeaee9
.long 0x47aeaee9
.long 0x10080818
.long 0x10080818
.long 0x6fbabad5
.long 0x6fbabad5
.long 0xf0787888
.long 0xf0787888
.long 0x4a25256f
.long 0x4a25256f
.long 0x5c2e2e72
.long 0x5c2e2e72
.long 0x381c1c24
.long 0x381c1c24
.long 0x57a6a6f1
.long 0x57a6a6f1
.long 0x73b4b4c7
.long 0x73b4b4c7
.long 0x97c6c651
.long 0x97c6c651
.long 0xcbe8e823
.long 0xcbe8e823
.long 0xa1dddd7c
.long 0xa1dddd7c
.long 0xe874749c
.long 0xe874749c
.long 0x3e1f1f21
.long 0x3e1f1f21
.long 0x964b4bdd
.long 0x964b4bdd
.long 0x61bdbddc
.long 0x61bdbddc
.long 0x0d8b8b86
.long 0x0d8b8b86
.long 0x0f8a8a85
.long 0x0f8a8a85
.long 0xe0707090
.long 0xe0707090
.long 0x7c3e3e42
.long 0x7c3e3e42
.long 0x71b5b5c4
.long 0x71b5b5c4
.long 0xcc6666aa
.long 0xcc6666aa
.long 0x904848d8
.long 0x904848d8
.long 0x06030305
.long 0x06030305
.long 0xf7f6f601
.long 0xf7f6f601
.long 0x1c0e0e12
.long 0x1c0e0e12
.long 0xc26161a3
.long 0xc26161a3
.long 0x6a35355f
.long 0x6a35355f
.long 0xae5757f9
.long 0xae5757f9
.long 0x69b9b9d0
.long 0x69b9b9d0
.long 0x17868691
.long 0x17868691
.long 0x99c1c158
.long 0x99c1c158
.long 0x3a1d1d27
.long 0x3a1d1d27
.long 0x279e9eb9
.long 0x279e9eb9
.long 0xd9e1e138
.long 0xd9e1e138
.long 0xebf8f813
.long 0xebf8f813
.long 0x2b9898b3
.long 0x2b9898b3
.long 0x22111133
.long 0x22111133
.long 0xd26969bb
.long 0xd26969bb
.long 0xa9d9d970
.long 0xa9d9d970
.long 0x078e8e89
.long 0x078e8e89
.long 0x339494a7
.long 0x339494a7
.long 0x2d9b9bb6
.long 0x2d9b9bb6
.long 0x3c1e1e22
.long 0x3c1e1e22
.long 0x15878792
.long 0x15878792
.long 0xc9e9e920
.long 0xc9e9e920
.long 0x87cece49
.long 0x87cece49
.long 0xaa5555ff
.long 0xaa5555ff
.long 0x50282878
.long 0x50282878
.long 0xa5dfdf7a
.long 0xa5dfdf7a
.long 0x038c8c8f
.long 0x038c8c8f
.long 0x59a1a1f8
.long 0x59a1a1f8
.long 0x09898980
.long 0x09898980
.long 0x1a0d0d17
.long 0x1a0d0d17
.long 0x65bfbfda
.long 0x65bfbfda
.long 0xd7e6e631
.long 0xd7e6e631
.long 0x844242c6
.long 0x844242c6
.long 0xd06868b8
.long 0xd06868b8
.long 0x824141c3
.long 0x824141c3
.long 0x299999b0
.long 0x299999b0
.long 0x5a2d2d77
.long 0x5a2d2d77
.long 0x1e0f0f11
.long 0x1e0f0f11
.long 0x7bb0b0cb
.long 0x7bb0b0cb
.long 0xa85454fc
.long 0xa85454fc
.long 0x6dbbbbd6
.long 0x6dbbbbd6
.long 0x2c16163a
.long 0x2c16163a
